<?php
/**
 * Custom template tags for this theme
 *
 * @package nidavellir
 */

if ( ! function_exists( 'nidavellir_posted_on' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time.
	 */
	function nidavellir_posted_on() {
		$nidavellir_time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$nidavellir_time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}
		$nidavellir_time_string = sprintf( $nidavellir_time_string,
			esc_attr( get_the_date( DATE_W3C ) ),
			esc_html( get_the_date() ),
			esc_attr( get_the_modified_date( DATE_W3C ) ),
			esc_html( get_the_modified_date() )
		);
		$nidavellir_posted_on = sprintf(
			/* translators: %s: post date. */
			esc_html_x( 'Posted on %s', 'post date', 'nidavellir' ),
			'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $nidavellir_time_string . '</a>'
		);
		echo '<span class="posted-on">' . $nidavellir_posted_on . '</span>'; // WPCS: XSS OK.
	}
endif;

if ( ! function_exists( 'nidavellir_posted_by' ) ) :
	/**
	 * Prints HTML with meta information for the current author.
	 */
	function nidavellir_posted_by() {
		$nidavellir_byline = sprintf(
			/* translators: %s: post author. */
			esc_html_x( 'by %s', 'post author', 'nidavellir' ),
			'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
		);
		echo '<span class="byline"> ' .  $nidavellir_byline . '</span>'; // WPCS: XSS OK.
	}
endif;

if ( ! function_exists( 'nidavellir_entry_footer' ) ) :
	/**
	 * Prints HTML with meta information for the categories, tags and comments.
	 */
	function nidavellir_entry_footer() {
		if ( 'post' === get_post_type() ) {
			/* translators: used between list items, there is a space after the comma */
			$nidavellir_categories_list = get_the_category_list( esc_html__( ', ', 'nidavellir' ) );
			if ( $nidavellir_categories_list ) {
				/* translators: 1: list of categories. */
				printf( '<span class="cat-links">' . esc_html__( 'Posted in %1$s', 'nidavellir' ) . '</span>', $nidavellir_categories_list ); // WPCS: XSS OK.
			}
			/* translators: used between list items, there is a space after the comma */
			$nidavellir_tags_list = get_the_tag_list( '', esc_html_x( ', ', 'list item separator', 'nidavellir' ) );
			if ( $nidavellir_tags_list ) {
				/* translators: 1: list of tags. */
				printf( '<span class="tags-links">' . esc_html__( 'Tagged %1$s', 'nidavellir' ) . '</span>', $nidavellir_tags_list ); // WPCS: XSS OK.
			}
		}
		if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			echo '<span class="comments-link">';
			comments_popup_link(
				sprintf(
					wp_kses(
						/* translators: %s: post title */
						__( 'Leave a Comment<span class="screen-reader-text"> on %s</span>', 'nidavellir' ),
						array(
							'span' => array(
								'class' => array(),
							),
						)
					),
					get_the_title()
				)
			);
			echo '</span>';
		}
		edit_post_link(
			sprintf(
				wp_kses(
					/* translators: %s: Name of current post. Only visible to screen readers */
					__( 'Edit <span class="screen-reader-text">%s</span>', 'nidavellir' ),
					array(
						'span' => array(
							'class' => array(),
						),
					)
				),
				get_the_title()
			),
			'<span class="edit-link">',
			'</span>'
		);
	}
endif;
